=======
Credits
=======

Project coordination
--------------------
* Andreas Tuerk <andreas.tuerk@lexogen.com>
* Falko Hofmann <falko.hofmann@lexogen.com>

Implementation
--------------
* Falko Hofmann <falko.hofmann@lexogen.com>
* Michael Moldaschl <michael.moldaschl@lexogen.com>

Error correction maps
---------------------
* Michael Moldaschl <michael.moldaschl@lexogen.com>

Test data generation
--------------------
* Gregor Entzian <gregor.entzian@lexogen.com>

Documentation & code revision
-----------------------------
* Andreas Tuerk <andreas.tuerk@lexogen.com>
* Michael Moldaschl <michael.moldaschl@lexogen.com>
* Gregor Entzian <gregor.entzian@lexogen.com>
* Lauren Sheehan <lauren.sheehan@lexogen.com>
* Gregor Wiktorin <gregor.wiktorin@lexogen.com>